@@ -85,6 +85,9 @@ void PlayListModel::getVideos(QString path)
 {
     clear();
     QUrl openedUrl(path);
+    if (openedUrl.scheme().isEmpty()) {
+        openedUrl.setScheme("file");
+    }
     QFileInfo openedFileInfo(openedUrl.toLocalFile());
     QStringList siblingFiles;
     if (openedFileInfo.exists() && openedFileInfo.isFile()) {
@@ -123,7 +126,7 @@ void PlayListModel::appendVideo(QString videoPath)
     QFileInfo videoPathInfo(videoPath);
     QStringList videoFiles;
     if (videoPathInfo.exists() && videoPathInfo.isFile()) {
-        QString mimeType = Application::mimeType(videoPathInfo.absoluteFilePath());
+        QString mimeType = Application::mimeType(QUrl(videoPathInfo.absoluteFilePath()));
         if (mimeType.startsWith("video/") || mimeType.startsWith("audio/")) {
             videoFiles.append(videoPathInfo.absoluteFilePath());
         }
