@@ -46,12 +46,13 @@ public:
     Q_INVOKABLE void setPlayingVideo(int playingVideo);
     Q_INVOKABLE int getPlayingVideo() const;
     Q_INVOKABLE void getVideos(QString path);
+    Q_INVOKABLE void appendVideo(QString videoPath);
     Q_INVOKABLE void clear();
 
     Playlist getPlayList() const;
     void setPlayList(const Playlist &playList);
 
-signals:
+Q_SIGNALS:
     void videoAdded(int index, QString path);
     void playingVideoChanged();
 
