@@ -30,7 +30,7 @@ Worker* Worker::instance()
 
 void Worker::getMetaData(int index, const QString &path)
 {
-    QString mimeType = Application::mimeType(path);
+    QString mimeType = Application::mimeType(QUrl(path));
     KFileMetaData::ExtractorCollection exCol;
     QList<KFileMetaData::Extractor*> extractors = exCol.fetchExtractors(mimeType);
     KFileMetaData::SimpleExtractionResult result(path, mimeType,
